@@ -219,6 +219,10 @@ class BaseLegacyConverter:
                         error = f"{model_record_key} has a download record without a sha256sum."
                         self.add_validation_error_to_log(model_record_key=model_record_key, error=error)
                         parsed_download_record.sha256sum = "FIXME"
+
+                    if download.get("file_type") and download["file_type"] == "ckpt":
+                        parsed_download_record.file_type = download["file_type"]
+
                     parsed_record_config_download_list.append(parsed_download_record)
 
         return parsed_record_config_download_list
@@ -277,7 +281,6 @@ class BaseLegacyConverter:
         """Override and call super().post_parse_records() to perform any model category specific post parsing."""
         for model_record in self.all_model_records.values():
             model_record.purpose = MODEL_PURPOSE_LOOKUP[self.model_reference_category]
-        pass
 
     def write_out_records(self) -> None:
         """Write out the parsed records."""
@@ -307,7 +310,8 @@ class BaseLegacyConverter:
             self.all_validation_errors_log[model_record_key] = []
         self.all_validation_errors_log[model_record_key].append(error)
 
-        logger.debug(f"{model_record_key} has error: {error}")
+        if self.debug_mode:
+            logger.debug(f"{model_record_key} has error: {error}")
 
     def write_out_validation_errors(self) -> None:
         """Write out the validation errors."""
@@ -487,13 +491,14 @@ class LegacyStableDiffusionConverter(BaseLegacyConverter):
                 error = f"folder '{folder}' is not in the model records."
                 self.add_validation_error_to_log(model_record_key=folder, error=error)
 
-        logger.debug(f"{self.all_styles=}")
-        logger.debug(f"{self.all_baseline_categories=}")
-        logger.debug(f"{self.all_tags=}")
-        logger.debug(f"{self.all_download_hosts=}")
-        logger.info(f"Total number of models: {len(self.all_model_records)}")
-        logger.info(f"Total number of showcase folders: {len(final_on_disk_showcase_folders_names)}")
-        logger.info(f"Total number of models with validation issues: {len(self.all_validation_errors_log)}")
+        if self.debug_mode:
+            logger.debug(f"{self.all_styles=}")
+            logger.debug(f"{self.all_baseline_categories=}")
+            logger.debug(f"{self.all_tags=}")
+            logger.debug(f"{self.all_download_hosts=}")
+            logger.info(f"Total number of models: {len(self.all_model_records)}")
+            logger.info(f"Total number of showcase folders: {len(final_on_disk_showcase_folders_names)}")
+            logger.info(f"Total number of models with validation issues: {len(self.all_validation_errors_log)}")
 
     @override
     def write_out_records(self) -> None:
@@ -546,8 +551,7 @@ class LegacyStableDiffusionConverter(BaseLegacyConverter):
                 + "\n",
             )
 
-        logger.info("Converted database passes validation and was written to disk successfully.")
-        logger.info(f"Converted database written to: {self.converted_database_file_path}")
+        logger.debug(f"Converted database written to: {self.converted_database_file_path}")
 
     def get_existing_showcases(
         self,
@@ -581,6 +585,8 @@ class LegacyStableDiffusionConverter(BaseLegacyConverter):
             baseline = "stable_diffusion_2_512"
         elif baseline == "stable_diffusion_xl":
             baseline = "stable_diffusion_xl"
+        elif baseline == "stable_cascade":
+            baseline = "stable_cascade"
         return baseline
 
     def create_showcase_folder(self, showcase_foldername: str) -> None:
