@@ -1,3 +1,4 @@
+import os
 from pathlib import Path
 
 from horde_model_reference.legacy.download_live_legacy_dbs import LegacyReferenceDownloadManager
@@ -13,9 +14,19 @@ def test_download_all_model_references(base_path_for_tests: Path):
 
 
 def test_validate_stable_diffusion_model_reference(legacy_folder_for_tests: Path):
-    assert validate_legacy_stable_diffusion_db(
-        sd_db=get_model_reference_file_path(
-            MODEL_REFERENCE_CATEGORY.stable_diffusion,
-            base_path=legacy_folder_for_tests,
-        ),
-    )
+    if os.environ.get("HORDELIB_CI_ONGOING"):
+        assert validate_legacy_stable_diffusion_db(
+            sd_db=get_model_reference_file_path(
+                MODEL_REFERENCE_CATEGORY.stable_diffusion,
+                base_path=legacy_folder_for_tests,
+            ),
+            fail_on_extra=True,
+        )
+    else:
+        assert validate_legacy_stable_diffusion_db(
+            sd_db=get_model_reference_file_path(
+                MODEL_REFERENCE_CATEGORY.stable_diffusion,
+                base_path=legacy_folder_for_tests,
+            ),
+            fail_on_extra=False,
+        )
